@@ -1,6 +1,6 @@
 /* atm.h - general ATM declarations */
  
-/* Written 1995 by Werner Almesberger, EPFL LRC */
+/* Written 1995,1996 by Werner Almesberger, EPFL LRC */
  
 
 #ifndef _LINUX_ATM_H
@@ -11,35 +11,39 @@
  * documentation. Do not change them.
  */
 
-
 #include <linux/atmsap.h>
+#include <linux/atmioc.h>
 
 
-#define ATM_CELL_SIZE	    53	/* ATM cell size incl. header */
-#define ATM_CELL_PAYLOAD    48	/* ATM payload size */
-#define ATM_MAX_AAL5_PDU 65535	/* maximum AAL5 PDU payload */
-#define ATM_MAX_CDV	  9999	/* maximum (default) CDV */
-#define ATM_NOT_RSV_VCI     32	/* first non-reserved VCI value */
+/* general ATM constants */
+#define ATM_CELL_SIZE		    53	/* ATM cell size incl. header */
+#define ATM_CELL_PAYLOAD	    48	/* ATM payload size */
+#define ATM_AAL0_SDU		    52	/* AAL0 SDU size */
+#define ATM_MAX_AAL34_PDU	 65535	/* maximum AAL3/4 PDU payload */
+#define ATM_AAL5_TRAILER	     8	/* AAL5 trailer size */
+#define ATM_MAX_AAL5_PDU	 65535	/* maximum AAL5 PDU payload */
+#define ATM_MAX_CDV		  9999	/* maximum (default) CDV */
+#define ATM_NOT_RSV_VCI		    32	/* first non-reserved VCI value */
 
-#define ATM_MAX_VPI	   255	/* maximum VPI at the UNI */
-#define ATM_MAX_VPI_NNI	  4096	/* maximum VPI at the NNI */
-#define ATM_MAX_VCI	 65535	/* maximum VCI */
+#define ATM_MAX_VPI		   255	/* maximum VPI at the UNI */
+#define ATM_MAX_VPI_NNI		  4096	/* maximum VPI at the NNI */
+#define ATM_MAX_VCI		 65535	/* maximum VCI */
 
 /*
  * The following items should be added to sys/socket.h aka linux/socket.h
  */
 
+/* address families */
 #define AF_ATMPVC	6		/* ATM PVCs */
 #define AF_ATMSVC	7		/* ATM SVCs */
 
+/* "protcol" values for the socket system call */
 #define ATM_AAL0	0		/* "raw" ATM cells */
 #define ATM_AAL1	1		/* AAL1 (CBR) */
 #define ATM_AAL2	2		/* AAL2 (VBR) */
 #define ATM_AAL34	3		/* AAL3/4 (data) */
 #define ATM_AAL5	5		/* AAL5 (data) */
 #define ATM_SAAL	12		/* signaling AAL */
-#define	ATM_CLIP	16		/* Classical IP over ATM, RFC1577 */
-#define ATM_ATMARP	17		/* ATM ARP - replaces CLIP */
 
 /*
  * UGLY - there should only be one protocol family (PF_ATM) for both
@@ -48,9 +52,11 @@
  * swimming against the stream ...
  */
 
+/* protocol families */
 #define PF_ATMPVC	AF_ATMPVC
 #define PF_ATMSVC	AF_ATMSVC
 
+/* layers for getsockopt/setsockopt */
 #define SOL_ATM		2
 #define SOL_AAL		3
 
@@ -58,6 +64,8 @@
 #define SO_SETCLP	1		/* set CLP bit value - TODO */
 #define SO_CIRANGE	3		/* connection identifier range;
 					   socket must be bound or connected */
+/* AAL layer */
+#define SO_AALTYPE	0		/* AAL type, get only */
 
 /* socket layer */
 #define SO_BCTXOPT	16		/* not ATM specific - should go */
@@ -133,7 +141,7 @@ struct atm_trafprm {
 	unsigned char	class;		/* traffic class (ATM_UBR, ...) */
 	int		max_pcr;	/* maximum PCR in cells per second */
 	int		min_pcr;	/* minimum PCR in cells per second */
-	int		max_cdv;	/* maximum CDV in cell slots */
+	int		max_cdv;	/* maximum CDV in microseconds */
 	int		max_sdu;	/* maximum SDU in bytes */
 };
 
@@ -157,7 +165,7 @@ struct sockaddr_atmpvc {
 	struct atm_trafprm sap_rxtp;	/* RX traffic parameters */
 };
 
-/* SVC addressing - not used yet */
+/* SVC addressing */
 
 #define	ATM_ESA_LEN	20		/* ATM End System Address length */
 #define ATM_E164_LEN	12		/* maximum E.164 number length */
@@ -186,16 +194,24 @@ struct sockaddr_atmsvc {
  * Some stuff for linux/sockios.h
  */
 
-#define SIOCSIFATMTCP	0x8982		/* set ATMTCP mode */
-#define SIOCGIFATMADDR	0x8983		/* get local ATM address */
-#define SIOCSIFATMADDR	0x8984		/* set local ATM address */
-
-
 struct atmif_sioc {
     int number;
+    int length;
     void *arg;
 };
 
+
+#define SIOCSIFATMTCP	_IO('a',ATMIOC_ITF)	/* set ATMTCP mode */
+
+/*
+ * The following ioctls are obsolete and will be removed in a later release
+ */
+
+#define SIOCGIFATMADDR	_IOR('a',ATMIOC_ITF+1,struct atmif_sioc)
+					/* get local ATM address */
+#define SIOCSIFATMADDR	_IOR('a',ATMIOC_ITF+2,struct atmif_sioc)
+					/* set local ATM address */
+
 #ifdef __KERNEL__
 
 #include <linux/net.h>	/* struct net_proto */
